
.. _leaderless programs:

===========================================
 2014-11-28 Process for Leaderless Programs
===========================================

Should the nomination period for Program Technical Lead close and any program
subject to the decisions of the Technical Committee not have a minimum of one
eligible candidate identify themselves, the following process will be used to
determine leadership for any program in this situation.

#. Programs without a minimum of one eligible candidate are identified to the
   Technical Committee by the Election Officials, before the conclusion of
   the election.

#. The Technical Committee can appoint a leader to any programs in this
   situation, by mutual agreement of the Technical Committee and the proposed
   appointee.

#. The appointed leader has all the same obligations and responsibilities as a
   self-nominated elected Program Technical Lead.
